# Yumbox (Yadgiri Machine Toolbox -- also yummy!)

Provides tools for:

- Caching results of functions
- Setting up logger and cache dir using config
- Image and text data loaders
- Easily create instances of ML models
- Evaluation metrics
- NLP tools
